@@ -166,8 +166,8 @@ class PointMassTrajectoryHSolver:
         self.preprocess_data['c_q'] = global_state['mcc_solver']['shell']['c_q']
         self.preprocess_data['theta_angle'] = data['initial_cond']['theta0']
         self.preprocess_data['v0'] = data['initial_cond']['V']
-        self.preprocess_data['cx_list'] = global_state['mcdrag_solver']['cx_list']
-        self.preprocess_data['mach_list'] = global_state['mcdrag_solver']['mach_list']
+        self.preprocess_data['cx_list'] = global_state['kontur_solver']['cx_list']
+        self.preprocess_data['mach_list'] = global_state['kontur_solver']['mach_list']
 
     def _get_fortran_shell(self):
 
