@@ -1,7 +1,7 @@
 import cffi, os, sys
 import numpy
 import numpy as np
-
+from typing import TypedDict
 
 def load_lib():
 
@@ -94,11 +94,23 @@ def load_lib():
 
 FFI, KONTUR_LIB = load_lib()
 
+class data(TypedDict):
+    ng: float
+    nh: float
+    nk: float
+    nfl: float
+    d: float
+    hb: float
+    xct: float
+    yint: float
+    geometry_data: list
+
+
 class KonturSolver:
 
     name = 'kontur_solver'
 
-    preprocessed_data = dict(
+    preprocessed_data: data = dict(
         ng=None,
         nh=None,
         nk=None,
@@ -109,6 +121,18 @@ class KonturSolver:
         yint=None,
         geometry_data=None
     )
+    def preprocessor(self, data: dict, global_state: dict):
+
+        self.preprocessed_data['ng'] = global_state['mcc_solver']['kontur']['ng']
+        self.preprocessed_data['nh'] = global_state['mcc_solver']['kontur']['nh']
+        self.preprocessed_data['nk'] = global_state['mcc_solver']['kontur']['nk']
+        self.preprocessed_data['nfl'] = global_state['mcc_solver']['kontur']['nfl']
+        self.preprocessed_data['d'] = global_state['mcc_solver']['kontur']['d']
+        self.preprocessed_data['hb'] = global_state['mcc_solver']['kontur']['hb']
+        self.preprocessed_data['xct'] = global_state['mcc_solver']['kontur']['xct']
+        self.preprocessed_data['yint'] = global_state['mcc_solver']['kontur']['yint']
+        self.preprocessed_data['geometry_data'] = global_state['mcc_solver']['kontur']['geometry_data']
+
 
     def run(self, data, global_state):
         p_data = self.preprocessed_data
@@ -160,25 +184,35 @@ class KonturSolver:
                 mesh_mxwx[i, j] = KONTUR_LIB.CSV_GetMxWx(solver)
                 mesh_mzwz[i, j] = KONTUR_LIB.CSV_GetMzWz(solver)
 
+        # global_state[KonturSolver.name] = dict(
+        #     mesh_tren=mesh_tren,
+        #     mesh_don=mesh_don,
+        #     mesh_voln=mesh_voln,
+        #     mesh_pois=mesh_pois,
+        #     mesh_cn=mesh_cn,
+        #     mesh_cy=mesh_cy,
+        #     mesh_xcd=mesh_xcd,
+        #     mesh_cx=mesh_cx,
+        #     mesh_cyal=mesh_cyal,
+        #     mesh_cmal=mesh_cmal,
+        #     mesh_mxwx=mesh_mxwx,
+        #     mesh_mzwz=mesh_mzwz
+        # )
         global_state[KonturSolver.name] = dict(
-            mesh_tren=mesh_tren,
-            mesh_don=mesh_don,
-            mesh_voln=mesh_voln,
-            mesh_pois=mesh_pois,
-            mesh_cn=mesh_cn,
-            mesh_cy=mesh_cy,
-            mesh_xcd=mesh_xcd,
-            mesh_cx=mesh_cx,
-            mesh_cyal=mesh_cyal,
-            mesh_cmal=mesh_cmal,
-            mesh_mxwx=mesh_mxwx,
-            mesh_mzwz=mesh_mzwz
+            cx_list=mesh_cx[0],
+            mach_list=mach_list
         )
 
 
+
 if __name__ == '__main__':
     import matplotlib.pyplot as plt
 
+
+
+
+
+
     def print_solver(solver):
         print(
             KONTUR_LIB.CSV_GetMach(solver),
