@@ -11,7 +11,7 @@ class data(TypedDict):
     explosive_material: np.ndarray
     belt_material: np.ndarray
     gun: dict
-
+    shell_size: dict
     corpus_coord: np.ndarray
     fuse_coord: np.ndarray
     explosive_coord: np.ndarray
@@ -32,7 +32,7 @@ class OFSMCCSolver:
         explosive_material=None,
         belt_material=None,
         gun=None,
-
+        shell_size=None,
         corpus_coord=None,
         fuse_coord=None,
         explosive_coord=None,
@@ -48,6 +48,7 @@ class OFSMCCSolver:
         self.preprocessed_data['explosive_material'] = data['materials']['explosive']
         self.preprocessed_data['belt_material'] = data['materials']['belt']
         self.preprocessed_data['gun'] = data['gun_char']
+        self.preprocessed_data['shell_size'] = data['shell_size']
 
         if self.flag:
             self.flag = False
@@ -381,6 +382,48 @@ class OFSMCCSolver:
 
         return new_size
 
+    # Определяем параметры для будущего расчёта
+    def get_params_for_kontur(self, data, state, xc):
+        sizes = data['shell_size']
+
+        ng = 3 #Количество разбиения ГЧ
+        nh = ng + 1 #Количество участков головной и цилиндрической частей
+        nk = 5  #Общее количество участков на снаряде
+        nfl = 2 # Вид притупления
+        yint = 0 # Высота носика (0 потому что задаётся отдельным примитивом)
+        d = sizes['d']  # Калибра снаряда
+        hb = sizes['R17'] - (d / 2)   # Высота пояска
+        xct = state['geometry_solver']['L_all'] - xc # Координата центра тяжести (ОТ НОСИКА !!!)
+
+
+        R_d = d / 2
+        # Колпачок взрывателя
+        fuse_nose = {'type': 1, 'x1': 0., 'x2': sizes['R29'], 'r1': sizes['R28'], 'r2': sizes['R28'], 'R': 0., 'n': 0.}
+        # Конус взрывателя
+        fuse_korp = {'type': 2, 'x1': sizes['R29'], 'x2': sizes['R27'], 'r1': sizes['R28'], 'r2': sizes['R9'], 'R': 0., 'n': 0.}
+        # Оживало снаряда
+        h_oj = sizes['R27'] + sizes['R8']
+        R_oj = state['geometry_solver']['Roj']
+        shell_ojive = {'type': 4, 'x1': sizes['R27'], 'x2': h_oj, 'r1': sizes['R9'], 'r2': R_d, 'R': R_oj, 'n': 0.}
+        # Цилиндр снаряда (до зпч)
+        h_cyl = h_oj + sizes['R7'] + sizes['R6'] + sizes['R4'] + sizes['R3'] + sizes['R2']
+        cyl_shell = {'type': 1, 'x1': h_oj, 'x2': h_cyl, 'r1': R_d, 'r2': R_d, 'R': 0., 'n': 0.}
+        # Конус ЗПЧ
+        r_zp = R_d - np.tan(sizes['R23']) * sizes['R1']
+        print(r_zp * 1000)
+        zp_konus = {'type': 2, 'x1': h_cyl, 'x2': h_cyl + sizes['R1'], 'r1': R_d, 'r2': r_zp, 'R': 0., 'n': 0.}
+
+        geometry_data = [fuse_nose, fuse_korp, shell_ojive, cyl_shell, zp_konus]
+
+        result = {'ng': ng, 'nh': nh, 'nk': nk, 'nfl': nfl, 'yint': yint, 'd': d, 'hb': hb, 'xct': xct,
+                  'geometry_data': geometry_data}
+
+        return result
+
+
+
+
+
     # Запуск расчёта
     def run(self, data: dict, state: dict):
 
@@ -444,12 +487,18 @@ class OFSMCCSolver:
 
             corpus_params['q_grove'] = self.q_grove
 
-            results = {'shell': res_shell, 'corp': corpus_params, 'expl': explosive_params, 'belt': belt_params, 'fuse': fuse_params,}
+            # Получаем параметры для будущего расчёта аэродинамики
+            kontur = self.get_params_for_kontur(p_data, state, xc)
+
+            results = {'shell': res_shell, 'corp': corpus_params, 'expl': explosive_params, 'belt': belt_params, 'fuse': fuse_params,
+                       'kontur': kontur}
 
             # self.results = results
             self.flag = True
+
             state[OFSMCCSolver.name] = results
 
+
 class APFSDMccSolver(ABCSolver):
 
     name = 'apfsd_mcc_solver'
