@@ -27,8 +27,8 @@ class data(TypedDict):
     mu: float
     q: float
     n: float
-    alpha_n: float
-    alpha_k: float
+    eta_n: float
+    eta_k: float
     Ln: float
     C: float
     mu_c: float
@@ -540,8 +540,8 @@ class StressSolver:
         mu=None,
         q=None,
         n=None,
-        alpha_n=None,
-        alpha_k=None,
+        eta_n=None,
+        eta_k=None,
         Ln=None,
         C=None,
         mu_c=None,
@@ -559,8 +559,8 @@ class StressSolver:
         self.preprocessed_data['d_d']=data['gun_char']['d_dn']
         self.preprocessed_data['d_p']=data['gun_char']['d']
         self.preprocessed_data['n']=data['gun_char']['n']
-        self.preprocessed_data['alpha_n']=data['gun_char']['theta_n']
-        self.preprocessed_data['alpha_k']=data['gun_char']['theta_k']
+        self.preprocessed_data['eta_n']=data['gun_char']['eta_n']
+        self.preprocessed_data['eta_k']=data['gun_char']['eta_k']
         self.preprocessed_data['Ln']=data['gun_char']['l_n']
         self.preprocessed_data['f0']=data['materials']['belt']['f0']
         self.preprocessed_data['mu_c']=data['materials']['explosive']['mu']
@@ -585,8 +585,8 @@ class StressSolver:
         mu = p_data['mu']
         q = p_data['q']
         n = p_data['n']
-        alpha_n = p_data['alpha_n']
-        alpha_k = p_data['alpha_k']
+        alpha_n = np.arctan(np.pi / p_data['eta_n'])
+        alpha_k = np.arctan(np.pi / p_data['eta_k'])
         Ln = p_data['Ln']
         C = p_data['C']
         mu_c = p_data['mu_c']
